@@ -1,13 +1,15 @@
+from __future__ import absolute_import, print_function
+
 from threading import Thread
 from time import sleep
 
 class MyThread(Thread):
     def run(self):
         sleep(2)
-        print "MyThread done"
+        print("MyThread done")
 
 my_thread = MyThread()
 
 my_thread.start()
-print "Main thread done"
+print("Main thread done")
 
