@@ -27,6 +27,14 @@ Notes:
    definition, which links the list of available entrees from the
    KitchenCapabilities object to the OrderMenu object's entree EnumEditor.
 
+ - The user can freely type any value they want, but only items in the
+   capabilities will be accepted, due to the use of the 'values' argument
+   to the Enum trait.  This will be updated as the capabilities change.
+
+ - With the Qt backend, the user can type text and it will be auto-completed
+   to valid values as a the user types. The Wx backend doesn't support this
+   capability in the underlying toolkit.
+
  - The design will work with any number of active OrderMenu objects, since they
    all share a common KitchenCapabilities object. As the KitchenCapabilities
    object is updated, all OrderMenu UI's will automatically update their
@@ -35,17 +43,20 @@ Notes:
  - A careful reader will also observe that this example contains only
    declarative code. No imperative code is required to handle the automatic
    updating of the Entree list.
+
 """
 
-#-- Imports --------------------------------------------------------------------
+from __future__ import absolute_import, unicode_literals
 
-from traits.api \
-    import HasPrivateTraits, Str, List, Constant
+import six
 
-from traitsui.api \
-    import View, Item, VGroup, HSplit, EnumEditor, CheckListEditor
+from traits.api import Enum, HasPrivateTraits, List, Constant
 
-#-- The list of possible entrees -----------------------------------------------
+from traitsui.api import (
+    View, Item, VGroup, HSplit, EnumEditor, CheckListEditor
+)
+
+#-- The list of possible entrees -----------------------------------------
 
 possible_entrees = [
     'Chicken Fried Steak',
@@ -59,53 +70,59 @@ possible_entrees = [
     'Cobb Salad'
 ]
 
-#-- The KitchenCapabilities class ----------------------------------------------
+#-- The KitchenCapabilities class ----------------------------------------
 
-class KitchenCapabilities ( HasPrivateTraits ):
+
+class KitchenCapabilities(HasPrivateTraits):
 
     # The current set of entrees the kitchen can make (based on its larder):
-    available = List( possible_entrees )
+    available = List(possible_entrees)
 
 # The KitchenCapabilities are shared by all waitstaff taking orders:
 kitchen_capabilities = KitchenCapabilities()
 
-#-- The OrderMenu class --------------------------------------------------------
+#-- The OrderMenu class --------------------------------------------------
 
-class OrderMenu ( HasPrivateTraits ):
+
+class OrderMenu(HasPrivateTraits):
 
     # The person's entree order:
-    entree = Str
+    entree = Enum(values='capabilities.available')
 
     # Reference to the restaurant's current entree capabilities:
-    capabilities = Constant( kitchen_capabilities )
+    capabilities = Constant(kitchen_capabilities)
 
     # The user interface view:
     view = View(
         HSplit(
             VGroup(
-                Item( 'entree',
-                      editor = EnumEditor(
-                                   name = 'object.capabilities.available' )
-                ),
-                label       = 'Order',
-                show_border = True,
-                dock        = 'tab'
+                Item('entree',
+                     editor=EnumEditor(
+                         name='object.capabilities.available',
+                         evaluate=six.text_type,
+                         completion_mode='popup',
+                        )
+                     ),
+                label='Order',
+                show_border=True,
+                dock='tab'
             ),
             VGroup(
-                Item( 'object.capabilities.available',
-                      show_label = False,
-                      style      = 'custom',
-                      editor     = CheckListEditor( values = possible_entrees )
-                ),
-                label       = 'Kitchen',
-                show_border = True,
-                dock        = 'tab'
+                Item('object.capabilities.available',
+                     show_label=False,
+                     style='custom',
+                     editor=CheckListEditor(values=possible_entrees)
+                     ),
+                label='Kitchen',
+                show_border=True,
+                dock='tab'
             )
         ),
-        title = 'Dynamic EnumEditor Demo',
+        title='Dynamic EnumEditor Demo',
+        resizable=True,
     )
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 # Create the demo:
 demo = OrderMenu()
@@ -113,4 +130,4 @@ demo = OrderMenu()
 # Run the demo (if invoked from the command line):
 if __name__ == '__main__':
     demo.configure_traits()
-
+    print(demo.entree)
