@@ -6,32 +6,34 @@ displaying lists of strings, or other data that can be logically mapped to a
 list of strings.
 """
 
+from __future__ import absolute_import
 from traits.api import HasTraits, List, Str
 from traitsui.api import View, Item, ListStrEditor
 
-#-- ShoppingListDemo Class -----------------------------------------------------
+#-- ShoppingListDemo Class -----------------------------------------------
 
-class ShoppingListDemo (HasTraits):
+
+class ShoppingListDemo(HasTraits):
 
     # The list of things to buy at the store:
     shopping_list = List(Str)
 
-    #-- Traits View Definitions ------------------------------------------------
+    #-- Traits View Definitions ----------------------------------------------
 
     view = View(
         Item('shopping_list',
-              show_label = False,
-              editor = ListStrEditor(title = 'Shopping List', auto_add = True)
-        ),
-        title     = 'Shopping List',
-        width     = 0.2,
-        height    = 0.5,
-        resizable = True
+             show_label=False,
+             editor=ListStrEditor(title='Shopping List', auto_add=True)
+             ),
+        title='Shopping List',
+        width=0.2,
+        height=0.5,
+        resizable=True
     )
 
-#-- Set up the Demo ------------------------------------------------------------
+#-- Set up the Demo ------------------------------------------------------
 
-demo = ShoppingListDemo(shopping_list = [
+demo = ShoppingListDemo(shopping_list=[
     'Carrots',
     'Potatoes (5 lb. bag)',
     'Cocoa Puffs',
@@ -47,4 +49,3 @@ demo = ShoppingListDemo(shopping_list = [
 # Run the demo (in invoked from the command line):
 if __name__ == '__main__':
     demo.configure_traits()
-
