@@ -24,6 +24,7 @@ appear in the GUI's enumerated list are determined by the *cities* attribute of
 the view's handler, as specified in the EnumEditor's *name* parameter.
 """
 
+from __future__ import absolute_import
 from traits.api import HasTraits, Str, Enum, List
 from traitsui.api import View, Item, Handler, EnumEditor
 
@@ -66,19 +67,19 @@ class Address(HasTraits):
     """
 
     street_address = Str
-    state          = Enum(cities.keys()[0], cities.keys())
-    city           = Str
+    state = Enum(list(cities.keys())[0], list(cities.keys()))
+    city = Str
 
     view = View(
-        Item(name  = 'street_address'),
-        Item(name  = 'state'),
-        Item(name  = 'city',
-             editor = EnumEditor(name = 'handler.cities'),
+        Item(name='street_address'),
+        Item(name='state'),
+        Item(name='city',
+             editor=EnumEditor(name='handler.cities'),
              ),
-        title     = 'Address Information',
-        buttons   = ['OK'],
-        resizable = True,
-        handler   = AddressHandler
+        title='Address Information',
+        buttons=['OK'],
+        resizable=True,
+        handler=AddressHandler
     )
 
 
@@ -86,6 +87,5 @@ class Address(HasTraits):
 demo = Address(street_address="4743 Dudley Lane")
 
 # Run the demo (if invoked from the command line):
-if __name__== '__main__':
+if __name__ == '__main__':
     demo.configure_traits()
-
