@@ -5,12 +5,14 @@
 # configure_traits_view.py -- Sample code to demonstrate configure_traits()
 
 
-#--[Imports]--------------------------------------------------------------------
+#--[Imports]--------------------------------------------------------------
+from __future__ import absolute_import
 from traits.api import HasTraits, Str, Int
 from traitsui.api import View, Item
 import traitsui
 
-#--[Code]-----------------------------------------------------------------------
+#--[Code]-----------------------------------------------------------------
+
 
 class SimpleEmployee(HasTraits):
     first_name = Str
@@ -19,10 +21,9 @@ class SimpleEmployee(HasTraits):
     employee_number = Str
     salary = Int
 
-view1 = View(Item(name = 'first_name'),
-             Item(name = 'last_name'),
-             Item(name = 'department'))
+view1 = View(Item(name='first_name'),
+             Item(name='last_name'),
+             Item(name='department'))
 
 sam = SimpleEmployee()
 sam.configure_traits(view=view1)
-
