@@ -1,7 +1,7 @@
 #  Copyright (c) 2007, Enthought, Inc.
 #  License: BSD Style.
 
-#--(Extended Traits UI Item and Editor References)------------------------------
+#--(Extended Traits UI Item and Editor References)------------------------
 """
 Extended Traits UI Item and Editor References
 =============================================
@@ -82,8 +82,9 @@ that the *team* trait is intialized to a valid value when a new **League**
 model is set up.
 """
 
-#--<Imports>--------------------------------------------------------------------
+#--<Imports>--------------------------------------------------------------
 
+from __future__ import absolute_import
 from traits.api \
     import *
 
@@ -92,144 +93,153 @@ from traitsui.api \
 
 from traitsui.table_column \
     import *
+from functools import reduce
 
-#--[Player Class]---------------------------------------------------------------
+#--[Player Class]---------------------------------------------------------
 
 # Define a baseball player:
-class Player ( HasTraits ):
+
+
+class Player(HasTraits):
 
     # The name of the player:
-    name = Str( '<new player>' )
+    name = Str('<new player>')
 
     # The number of hits the player made this season:
     hits = Int
 
-#--[Team Class]-----------------------------------------------------------------
+#--[Team Class]-----------------------------------------------------------
 
 # Define a baseball team:
-class Team ( HasTraits ):
+
+
+class Team(HasTraits):
 
     # The name of the team:
-    name = Str( '<new team>' )
+    name = Str('<new team>')
 
     # The players on the team:
-    players = List( Player )
+    players = List(Player)
 
     # The number of players on the team:
-    num_players = Property( depends_on = 'players' )
+    num_players = Property(depends_on='players')
 
-    def _get_num_players ( self ):
+    def _get_num_players(self):
         """ Implementation of the 'num_players' property.
         """
-        return len( self.players )
+        return len(self.players)
 
-#--[League Class]---------------------------------------------------------------
+#--[League Class]---------------------------------------------------------
 
 # Define a baseball league model:
-class League ( HasTraits ):
+
+
+class League(HasTraits):
 
     # The name of the league:
-    name = Str( '<new league>' )
+    name = Str('<new league>')
 
     # The teams in the league:
-    teams = List( Team )
+    teams = List(Team)
 
 #--[LeagueModelView Class]-----------------------------------------------------
 
 # Define a ModelView for a League model:
-class LeagueModelView ( ModelView ):
+
+
+class LeagueModelView(ModelView):
 
     # The currently selected team:
-    team = Instance( Team )
+    team = Instance(Team)
 
     # The currently selected player:
-    player = Instance( Player )
+    player = Instance(Player)
 
     # Button to add a hit to the current player:
-    got_hit = Button( 'Got a Hit' )
+    got_hit = Button('Got a Hit')
 
     # The total number of hits
-    total_hits = Property( depends_on = 'model.teams.players.hits' )
+    total_hits = Property(depends_on='model.teams.players.hits')
 
     @cached_property
-    def _get_total_hits ( self ):
+    def _get_total_hits(self):
         """ Returns the total number of hits across all teams and players.
         """
         return 0
-        return reduce( add, [ reduce( add, [ p.hits for p in t.players ], 0 )
-                              for t in self.model.teams ], 0 )
+        return reduce(add, [reduce(add, [p.hits for p in t.players], 0)
+                            for t in self.model.teams], 0)
 
     view = View(
         VGroup(
             HGroup(
-                Item( 'total_hits', style = 'readonly' ),
-                      label       = 'League Statistics',
-                      show_border = True
+                Item('total_hits', style='readonly'),
+                label='League Statistics',
+                show_border=True
             ),
             VGroup(
-                Item( 'model.teams',
-                      show_label = False,
-                      editor = TableEditor(
-                                columns = [ ObjectColumn( name  = 'name',
-                                                          width = 0.70 ),
-                                            ObjectColumn( name  = 'num_players',
-                                                          label = '# Players',
-                                                          editable = False,
-                                                          width = 0.29 ) ],
-                                selected     = 'object.team',
-                                auto_add     = True,
-                                row_factory  = Team,
-                                configurable = False,
-                                sortable     = False )
-                ),
-                label       = 'League Teams',
-                show_border = True
+                Item('model.teams',
+                     show_label=False,
+                     editor=TableEditor(
+                         columns=[ObjectColumn(name='name',
+                                               width=0.70),
+                                  ObjectColumn(name='num_players',
+                                               label='# Players',
+                                               editable=False,
+                                               width=0.29)],
+                         selected='object.team',
+                         auto_add=True,
+                         row_factory=Team,
+                         configurable=False,
+                         sortable=False)
+                     ),
+                label='League Teams',
+                show_border=True
             ),
             VGroup(
-                Item( 'object.team.players', # <-- Extended Item name
-                      show_label = False,
-                      editor = TableEditor(
-                                   columns  = [ ObjectColumn( name  = 'name',
-                                                              width = 0.70 ),
-                                                ObjectColumn( name  = 'hits',
-                                                              editable = False,
-                                                              width = 0.29 ) ],
-                                   selected     = 'object.player',
-                                   auto_add     = True,
-                                   row_factory  = Player,
-                                   configurable = False,
-                                   sortable     = False )
-                ),
+                Item('object.team.players',  # <-- Extended Item name
+                     show_label=False,
+                     editor=TableEditor(
+                         columns=[ObjectColumn(name='name',
+                                               width=0.70),
+                                  ObjectColumn(name='hits',
+                                               editable=False,
+                                               width=0.29)],
+                         selected='object.player',
+                         auto_add=True,
+                         row_factory=Player,
+                         configurable=False,
+                         sortable=False)
+                     ),
                 '_',
                 HGroup(
-                    Item( 'got_hit',
-                          show_label   = False,
-                          enabled_when = 'player is not None'
-                    )
+                    Item('got_hit',
+                         show_label=False,
+                         enabled_when='player is not None'
+                         )
                 ),
-                label       = 'Team Players',
-                show_labels = False,
-                show_border = True
+                label='Team Players',
+                show_labels=False,
+                show_border=True
             )
         ),
-        resizable = True
+        resizable=True
     )
 
-    def _model_changed ( self, model ):
+    def _model_changed(self, model):
         """ Handles the 'league' model being initialized.
         """
-        if len( model.teams ) > 0:
+        if len(model.teams) > 0:
             self.team = model.teams[0]
 
-    def _got_hit_changed ( self ):
+    def _got_hit_changed(self):
         """ Handles the currently selected player making a hit.
         """
         self.player.hits += 1
 
-    def _team_changed ( self, team ):
+    def _team_changed(self, team):
         """ Handles a new team being selected.
         """
-        if len( team.players ) > 0:
+        if len(team.players) > 0:
             self.player = team.players[0]
         else:
             self.player = None
@@ -237,28 +247,28 @@ class LeagueModelView ( ModelView ):
 # Function to add two numbers (used with 'reduce'):
 add = lambda a, b: a + b
 
-#--[Example*]-------------------------------------------------------------------
+#--[Example*]-------------------------------------------------------------
 
 # Define some sample teams and players:
-blue_birds = Team( name = 'Blue Birds', players = [
-    Player( name = 'Mike Scott',     hits = 25 ),
-    Player( name = 'Willy Shofield', hits = 37 ),
-    Player( name = 'Tony Barucci',   hits = 19 ) ] )
+blue_birds = Team(name='Blue Birds', players=[
+    Player(name='Mike Scott', hits=25),
+    Player(name='Willy Shofield', hits=37),
+    Player(name='Tony Barucci', hits=19)])
 
-chicken_hawks = Team( name = 'Chicken Hawks', players = [
-    Player( name = 'Jimmy Domore',   hits = 34 ),
-    Player( name = 'Bill Janks',     hits = 16 ),
-    Player( name = 'Tim Saunders',   hits = 27 ) ] )
+chicken_hawks = Team(name='Chicken Hawks', players=[
+    Player(name='Jimmy Domore', hits=34),
+    Player(name='Bill Janks', hits=16),
+    Player(name='Tim Saunders', hits=27)])
 
-eagles = Team( name = 'Eagles', players = [
-    Player( name = 'Joe Peppers',    hits = 33 ),
-    Player( name = 'Sam Alone',      hits = 12 ),
-    Player( name = 'Roger Clemson',  hits = 23 ) ] )
+eagles = Team(name='Eagles', players=[
+    Player(name='Joe Peppers', hits=33),
+    Player(name='Sam Alone', hits=12),
+    Player(name='Roger Clemson', hits=23)])
 
 # Create a league and its corresponding model view:
 demo = LeagueModelView(
-    League( name  = 'National Baseball Conference',
-            teams = [ blue_birds, chicken_hawks, eagles ] )
+    League(name='National Baseball Conference',
+           teams=[blue_birds, chicken_hawks, eagles])
 )
 
 
