@@ -24,13 +24,45 @@ try:
 except ImportError:
     pass
 
-from .api import (toolkit, BooleanEditor, ButtonEditor,
-    CheckListEditor, CodeEditor, ColorEditor, CompoundEditor, CustomEditor,
-    DateEditor, DefaultOverride, DirectoryEditor, DNDEditor, DropEditor,
-    EnumEditor, FileEditor, FontEditor, KeyBindingEditor, ImageEditor,
-    ImageEnumEditor, InstanceEditor, ListEditor, ListStrEditor, NullEditor,
-    RangeEditor, RGBColorEditor, SetEditor, TextEditor, TableEditor,
-    TimeEditor, TitleEditor, TreeEditor, TupleEditor, HistoryEditor,
-    HTMLEditor, PopupEditor, ValueEditor, ShellEditor, ScrubberEditor,
-    TabularEditor, ProgressEditor, SearchEditor)
-
+from .api import (
+    toolkit,
+    BooleanEditor,
+    ButtonEditor,
+    CheckListEditor,
+    CodeEditor,
+    ColorEditor,
+    CompoundEditor,
+    CustomEditor,
+    DateEditor,
+    DefaultOverride,
+    DirectoryEditor,
+    DNDEditor,
+    DropEditor,
+    EnumEditor,
+    FileEditor,
+    FontEditor,
+    KeyBindingEditor,
+    ImageEditor,
+    ImageEnumEditor,
+    InstanceEditor,
+    ListEditor,
+    ListStrEditor,
+    NullEditor,
+    RangeEditor,
+    RGBColorEditor,
+    SetEditor,
+    TextEditor,
+    TableEditor,
+    TimeEditor,
+    TitleEditor,
+    TreeEditor,
+    TupleEditor,
+    HistoryEditor,
+    HTMLEditor,
+    PopupEditor,
+    ValueEditor,
+    ShellEditor,
+    ScrubberEditor,
+    TabularEditor,
+    ProgressEditor,
+    SearchEditor)
