@@ -19,55 +19,57 @@
     a Traits-based user interface.
 """
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Imports:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 from __future__ import absolute_import
 
 import re
 
-from string import find, rfind
-
 from traits.api import (Bool, Callable, Constant, Delegate, Float, Instance,
-    Range, Str, Undefined, Dict,)
+                        Range, Str, Undefined, Dict,)
 
 from traits.trait_base import user_name_for
 
 from .view_element import ViewSubElement
 
-from .ui_traits import convert_theme, ContainerDelegate, EditorStyle
+from .ui_traits import ContainerDelegate, EditorStyle
+
+from .util import str_find, str_rfind
 
 from .editor_factory import EditorFactory
+import six
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Constants:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 # Pattern of all digits:
-all_digits = re.compile( r'\d+' )
+all_digits = re.compile(r'\d+')
 
 # Pattern for finding size infomation embedded in an item description:
-size_pat = re.compile( r"^(.*)<(.*)>(.*)$", re.MULTILINE | re.DOTALL )
+size_pat = re.compile(r"^(.*)<(.*)>(.*)$", re.MULTILINE | re.DOTALL)
 
 # Pattern for finding tooltip infomation embedded in an item description:
-tooltip_pat = re.compile( r"^(.*)`(.*)`(.*)$", re.MULTILINE | re.DOTALL )
+tooltip_pat = re.compile(r"^(.*)`(.*)`(.*)$", re.MULTILINE | re.DOTALL)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Trait definitions:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 # Reference to an EditorFactory:
-ItemEditor = Instance( EditorFactory, allow_none = True )
+ItemEditor = Instance(EditorFactory, allow_none=True)
 
 # Amount of padding to add around an item:
-Padding = Range( -15, 15, 0, desc = 'amount of padding to add around item' )
+Padding = Range(-15, 15, 0, desc='amount of padding to add around item')
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'Item' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class Item ( ViewSubElement ):
+
+class Item(ViewSubElement):
     """ An element in a Traits-based user interface.
 
     Magic:
@@ -75,13 +77,13 @@ class Item ( ViewSubElement ):
     - Items are rendered as layout elements if :attr:`name` is set to
       special values:
 
-      * name='', the item is rendered as a static label
+      * ``name=''``, the item is rendered as a static label
 
-      * name='_', the item is rendered as a separator
+      * ``name='_'``, the item is rendered as a separator
 
-      * name=' ', the item is rendered as a 5 pixel spacer
+      * ``name=' '``, the item is rendered as a 5 pixel spacer
 
-      * name='23' (any number), the item is rendered as a spacer of
+      * ``name='23'`` (any number), the item is rendered as a spacer of
         the size specified (number of pixels)
     """
 
@@ -89,9 +91,9 @@ class Item ( ViewSubElement ):
     # _GroupPanel._add_items in qt/ui_panel.py, which is a very unlikely place
     # to look for it. Ideally, that logic should be in this class.
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Trait definitions:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     # A unique identifier for the item. If not set, it defaults to the value
     # of **name**.
@@ -129,17 +131,11 @@ class Item ( ViewSubElement ):
     # Image to display on notebook tabs:
     image = ContainerDelegate
 
-    # The theme to use for the item itself:
-    item_theme = ContainerDelegate
-
-    # The theme to use for the item's label:
-    label_theme = ContainerDelegate
-
     # Category of elements dragged from view:
     export = ContainerDelegate
 
     # Should a label be displayed for the item?
-    show_label = Delegate( 'container', 'show_labels' )
+    show_label = Delegate('container', 'show_labels')
 
     # Editor to use for the item:
     editor = ItemEditor
@@ -154,25 +150,25 @@ class Item ( ViewSubElement ):
     # whatever space it is explicitly (or implicitly) assigned. The default
     # value of Undefined means that the use (or non-use) of extra space will be
     # determined by the editor associated with the item.
-    resizable = Bool( Undefined )
+    resizable = Bool(Undefined)
 
     # Should the item use extra space along its Group's layout axis? For
     # example, it a vertical group, should an item expand vertically to use
     # any extra space available in the group?
-    springy = Bool( False )
+    springy = Bool(False)
 
     # Should the item use any extra space along its Group's non-layout
     # orientation? For example, in a vertical group, should an item expand
     # horizontally to the full width of the group? If left to the default value
     # of Undefined, the decision will be left up to the associated item editor.
-    full_size = Bool( Undefined )
+    full_size = Bool(Undefined)
 
     # Should the item's label use emphasized text? If the label is not shown,
     # this attribute is ignored.
-    emphasized = Bool( False )
+    emphasized = Bool(False)
 
     # Should the item receive focus initially?
-    has_focus = Bool( False )
+    has_focus = Bool(False)
 
     # Pre-condition for including the item in the display. If the expression
     # evaluates to False, the item is not defined in the display. Conditions
@@ -238,7 +234,7 @@ class Item ( ViewSubElement ):
     # 50% of the available width. The available width is the total width of the
     # view minus the width of any item's with fixed pixel sizes (i.e. width
     # values not in the 0.0 to 1.0 range).
-    width = Float( -1.0 )
+    width = Float(-1.0)
 
     # Requested height of the editor (in pixels or fraction of available
     # height). For pixel values (i.e. values not in the range from 0.0 to 1.0),
@@ -257,71 +253,72 @@ class Item ( ViewSubElement ):
     # 50% of the available height. The available height is the total height of
     # the view minus the height of any item's with fixed pixel sizes (i.e.
     # height values not in the 0.0 to 1.0 range).
-    height = Float( -1.0 )
+    height = Float(-1.0)
 
     # The extended trait name of the trait containing the item's invalid state
     # status (passed through to the item's editor):
     invalid = Str
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Initialize the object:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def __init__ ( self, value = None, **traits ):
+    def __init__(self, value=None, **traits):
         """ Initializes the item object.
         """
-        super( Item, self ).__init__( **traits )
+        super(Item, self).__init__(**traits)
 
         if value is None:
             return
 
-        if not isinstance( value, basestring ):
-            raise TypeError, ("The argument to Item must be a string of the "
-                 "form: [id:][object.[object.]*][name]['['label']']`tooltip`"
-                 "[<width[,height]>][#^][$|@|*|~|;style]")
+        if not isinstance(value, six.string_types):
+            raise TypeError(
+                "The argument to Item must be a string of the "
+                "form: [id:][object.[object.]*][name]['['label']']`tooltip`"
+                "[<width[,height]>][#^][$|@|*|~|;style]")
 
-        value, empty = self._parse_label( value )
+        value, empty = self._parse_label(value)
         if empty:
             self.show_label = False
 
-        value = self._parse_style( value )
-        value = self._parse_size(  value )
-        value = self._parse_tooltip( value )
-        value = self._option( value, '#',  'resizable',  True )
-        value = self._option( value, '^',  'emphasized', True )
-        value = self._split( 'id',     value, ':', find,  0, 1 )
-        value = self._split( 'object', value, '.', rfind, 0, 1 )
+        value = self._parse_style(value)
+        value = self._parse_size(value)
+        value = self._parse_tooltip(value)
+        value = self._option(value, '#', 'resizable', True)
+        value = self._option(value, '^', 'emphasized', True)
+        value = self._split('id', value, ':', str_find, 0, 1)
+        value = self._split('object', value, '.', str_rfind, 0, 1)
 
         if value != '':
             self.name = value
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Returns whether or not the object is replacable by an Include object:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def is_includable ( self ):
+    def is_includable(self):
         """ Returns a Boolean indicating whether the object is replaceable by an
             Include object.
         """
         return (self.id != '')
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Returns whether or not the Item represents a spacer or separator:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def is_spacer ( self ):
+    def is_spacer(self):
         """ Returns True if the item represents a spacer or separator.
         """
         name = self.name.strip()
 
         return ((name == '') or (name == '_') or
-                (all_digits.match( name ) is not None))
+                (all_digits.match(name) is not None))
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Gets the help text associated with the Item in a specified UI:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def get_help ( self, ui ):
+    def get_help(self, ui):
         """ Gets the help text associated with the Item in a specified UI.
         """
         # Return 'None' if the Item is a separator or spacer:
@@ -332,15 +329,15 @@ class Item ( ViewSubElement ):
         if self.help != '':
             return self.help
 
-        object = eval( self.object_, globals(), ui.context )
+        object = eval(self.object_, globals(), ui.context)
 
-        return object.base_trait( self.name ).get_help()
+        return object.base_trait(self.name).get_help()
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Gets the label to use for a specified Item in a specified UI:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def get_label ( self, ui ):
+    def get_label(self, ui):
         """ Gets the label to use for a specified Item.
 
         If not specified, the label is set as the name of the
@@ -363,15 +360,15 @@ class Item ( ViewSubElement ):
         if label != '':
             return label
 
-        name   = self.name
-        object = eval( self.object_, globals(), ui.context )
-        trait  = object.base_trait( name )
-        label  = user_name_for( name )
+        name = self.name
+        object = eval(self.object_, globals(), ui.context)
+        trait = object.base_trait(name)
+        label = user_name_for(name)
         tlabel = trait.label
         if tlabel is None:
             return label
 
-        if isinstance( tlabel, basestring ):
+        if isinstance(tlabel, six.string_types):
             if tlabel[0:3] == '...':
                 return label + tlabel[3:]
             if tlabel[-3:] == '...':
@@ -380,13 +377,13 @@ class Item ( ViewSubElement ):
                 return self.label
             return tlabel
 
-        return tlabel( object, name, label )
+        return tlabel(object, name, label)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Returns an id used to identify the item:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def get_id ( self ):
+    def get_id(self):
         """ Returns an ID used to identify the item.
         """
         if self.id != '':
@@ -394,171 +391,181 @@ class Item ( ViewSubElement ):
 
         return self.name
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Parses a '<width,height>' value from the string definition:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def _parse_size ( self, value ):
+    def _parse_size(self, value):
         """ Parses a '<width,height>' value from the string definition.
         """
-        match = size_pat.match( value )
+        match = size_pat.match(value)
         if match is not None:
-            data  = match.group( 2 )
-            value = match.group( 1 ) + match.group( 3 )
-            col   = data.find( ',' )
+            data = match.group(2)
+            value = match.group(1) + match.group(3)
+            col = data.find(',')
             if col < 0:
-                self._set_float( 'width', data )
+                self._set_float('width', data)
             else:
-                self._set_float( 'width',  data[ : col ] )
-                self._set_float( 'height', data[ col + 1: ] )
+                self._set_float('width', data[: col])
+                self._set_float('height', data[col + 1:])
 
         return value
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Parses a '`tooltip`' value from the string definition:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def _parse_tooltip ( self, value ):
+    def _parse_tooltip(self, value):
         """ Parses a *tooltip* value from the string definition.
         """
-        match = tooltip_pat.match( value )
+        match = tooltip_pat.match(value)
         if match is not None:
-            self.tooltip = match.group( 2 )
-            value        = match.group( 1 ) + match.group( 3 )
+            self.tooltip = match.group(2)
+            value = match.group(1) + match.group(3)
 
         return value
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Sets a specified trait to a specified string converted to a float:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def _set_float ( self, name, value ):
+    def _set_float(self, name, value):
         """ Sets a specified trait to a specified string converted to a float.
         """
         value = value.strip()
         if value != '':
-            setattr( self, name, float( value ) )
+            setattr(self, name, float(value))
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Returns a 'pretty print' version of the Item:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def __repr__ ( self ):
+    def __repr__(self):
         """ Returns a "pretty print" version of the Item.
         """
 
-        options = self._repr_options( 'id', 'object', 'label', 'style',
-                                      'show_label', 'width', 'height' )
+        options = self._repr_options('id', 'object', 'label', 'style',
+                                     'show_label', 'width', 'height')
         if options is None:
             return "Item( '%s' )" % self.name
 
         return "Item( '%s'\n%s\n)" % (
-               self.name, self._indent( options, '      ' ) )
+               self.name, self._indent(options, '      '))
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'UItem' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class UItem ( Item ):
+
+class UItem(Item):
     """ An Item that has no label.
     """
 
-    show_label = Bool( False )
+    show_label = Bool(False)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'Custom' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class Custom ( Item ):
+
+class Custom(Item):
     """ An Item using a 'custom' style.
     """
 
-    style = EditorStyle( 'custom' )
+    style = EditorStyle('custom')
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'UCustom' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class UCustom ( Custom ):
+
+class UCustom(Custom):
     """ An Item using a 'custom' style with no label.
     """
 
-    show_label = Bool( False )
+    show_label = Bool(False)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'Readonly' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class Readonly ( Item ):
+
+class Readonly(Item):
     """ An Item using a 'readonly' style.
     """
 
-    style = EditorStyle( 'readonly' )
+    style = EditorStyle('readonly')
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'UReadonly' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class UReadonly ( Readonly ):
+
+class UReadonly(Readonly):
     """ An Item using a 'readonly' style with no label.
     """
 
-    show_label = Bool( False )
+    show_label = Bool(False)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'Label' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class Label ( Item ):
+
+class Label(Item):
     """ An item that is a label.
     """
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Initializes the object:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def __init__ ( self, label, item_theme = None, **traits ):
-        super( Label, self ).__init__(
-            label      = label,
-            item_theme = convert_theme( item_theme ),
+    def __init__(self, label, **traits):
+        super(Label, self).__init__(
+            label=label,
             **traits
         )
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'Heading' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class Heading ( Label ):
+
+class Heading(Label):
     """ An item that is a fancy label.
     """
 
     # Override the 'style' trait to default to the fancy 'custom' style:
-    style = Constant( 'custom' )
+    style = Constant('custom')
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'Spring' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class Spring ( Item ):
+
+class Spring(Item):
     """ An item that is a layout "spring".
     """
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Trait definitions:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     # Name of the trait the item is editing
-    name = 'spring'
+    # Just a dummy trait that exists on all HasTraits objects. It's an Event,
+    # so it won't cause Traits UI to add any synchronization, and because it
+    # already exists, it won't force the addition of a new trait with a bogus
+    # name.
+    name = 'trait_modified'
 
     # Should a label be displayed?
-    show_label = Bool( False )
+    show_label = Bool(False)
 
     # Editor to use for the item
-    editor = Instance( 'traitsui.api.NullEditor', () )
+    editor = Instance('traitsui.api.NullEditor', ())
 
     # Should the item use extra space along its Group's layout orientation?
     springy = True
 
 # A pre-defined spring for convenience
 spring = Spring()
-
