@@ -12,30 +12,33 @@
 """ Defines the table model used by the table editor.
 """
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Imports:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
+from __future__ import absolute_import
 from pyface.qt import QtCore, QtGui
 
 from traitsui.ui_traits import SequenceTypes
 
 from .clipboard import PyMimeData
 
-#-------------------------------------------------------------------------------
+import six
+
+#-------------------------------------------------------------------------
 #  Constants:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 # Mapping for trait alignment values to qt4 horizontal alignment constants
 h_alignment_map = {
-    'left':   QtCore.Qt.AlignLeft,
+    'left': QtCore.Qt.AlignLeft,
     'center': QtCore.Qt.AlignHCenter,
-    'right':  QtCore.Qt.AlignRight,
+    'right': QtCore.Qt.AlignRight,
 }
 
 # Mapping for trait alignment values to qt4 vertical alignment constants
 v_alignment_map = {
-    'top':    QtCore.Qt.AlignTop,
+    'top': QtCore.Qt.AlignTop,
     'center': QtCore.Qt.AlignVCenter,
     'bottom': QtCore.Qt.AlignBottom,
 }
@@ -43,6 +46,7 @@ v_alignment_map = {
 # MIME type for internal table drag/drop operations
 mime_type = 'traits-ui-table-editor'
 
+
 def as_qcolor(color):
     """ Convert a color specification (maybe a tuple) into a QColor.
     """
@@ -51,9 +55,10 @@ def as_qcolor(color):
     else:
         return QtGui.QColor(color)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'TableModel' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
+
 
 class TableModel(QtCore.QAbstractTableModel):
     """The model for table data."""
@@ -65,9 +70,9 @@ class TableModel(QtCore.QAbstractTableModel):
 
         self._editor = editor
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  QAbstractTableModel interface:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def rowCount(self, mi):
         """Reimplemented to return the number of rows."""
@@ -85,6 +90,11 @@ class TableModel(QtCore.QAbstractTableModel):
         obj = self._editor.items()[mi.row()]
         column = self._editor.columns[mi.column()]
 
+        if self._editor.factory is None:
+            # XXX This should never happen, but it does,
+            # probably during shutdown, but I haven't investigated
+            return None
+
         if role == QtCore.Qt.DisplayRole or role == QtCore.Qt.EditRole:
             text = column.get_value(obj)
             if text is not None:
@@ -102,6 +112,8 @@ class TableModel(QtCore.QAbstractTableModel):
 
         elif role == QtCore.Qt.FontRole:
             font = column.get_text_font(obj)
+            if font is None:
+                font = self._editor.factory.cell_font
             if font is not None:
                 return QtGui.QFont(font)
 
@@ -115,15 +127,21 @@ class TableModel(QtCore.QAbstractTableModel):
         elif role == QtCore.Qt.BackgroundRole:
             color = column.get_cell_color(obj)
             if color is None:
-                # FIXME: Yes, this is weird. It should work fine to fall through
-                # to the catch-all None at the end, but it doesn't.
-                return None
-            else:
-                q_color = as_qcolor(color)
-                return QtGui.QBrush(q_color)
+                if column.is_editable(obj):
+                    color = self._editor.factory.cell_bg_color_
+                else:
+                    color = self._editor.factory.cell_read_only_bg_color_
+                if color is None:
+                    # FIXME: Yes, this is weird. It should work fine to fall through
+                    # to the catch-all None at the end, but it doesn't.
+                    return None
+            q_color = as_qcolor(color)
+            return QtGui.QBrush(q_color)
 
         elif role == QtCore.Qt.ForegroundRole:
             color = column.get_text_color(obj)
+            if color is None:
+                color = self._editor.factory.cell_color_
             if color is not None:
                 q_color = as_qcolor(color)
                 return QtGui.QBrush(q_color)
@@ -152,28 +170,29 @@ class TableModel(QtCore.QAbstractTableModel):
                 return QtCore.Qt.NoItemFlags
 
         flags = QtCore.Qt.ItemIsSelectable | QtCore.Qt.ItemIsEnabled | \
-                QtCore.Qt.ItemIsDragEnabled
+            QtCore.Qt.ItemIsDragEnabled
 
         obj = editor.items()[mi.row()]
         column = editor.columns[mi.column()]
 
-        if editor.factory.editable and column.is_editable(obj):
-            flags |= QtCore.Qt.ItemIsEditable | QtCore.Qt.ItemIsDropEnabled
+        if editor.factory:
+            if editor.factory.editable and column.is_editable(obj):
+                flags |= QtCore.Qt.ItemIsEditable | QtCore.Qt.ItemIsDropEnabled
 
-        if editor.factory.reorderable:
-            flags |= QtCore.Qt.ItemIsDropEnabled
+            if editor.factory.reorderable:
+                flags |= QtCore.Qt.ItemIsDropEnabled
 
-        if column.get_type(obj) == "bool" and column.show_checkbox:
-            flags |= QtCore.Qt.ItemIsUserCheckable
+            if column.get_type(obj) == "bool" and column.show_checkbox:
+                flags |= QtCore.Qt.ItemIsUserCheckable
 
         return flags
 
     def headerData(self, section, orientation, role):
         """Reimplemented to return the header data."""
 
-        if orientation == QtCore.Qt.Horizontal:
+        editor = self._editor
 
-            editor = self._editor
+        if orientation == QtCore.Qt.Horizontal:
             column = editor.columns[section]
 
             if role == QtCore.Qt.DisplayRole:
@@ -184,6 +203,26 @@ class TableModel(QtCore.QAbstractTableModel):
             if role == QtCore.Qt.DisplayRole:
                 return str(section + 1)
 
+        if editor.factory is None:
+            # XXX This should never happen, but it does,
+            # probably during shutdown, but I haven't investigated
+            return None
+
+        if role == QtCore.Qt.FontRole:
+            font = editor.factory.label_font
+            if font is not None:
+                return QtGui.QFont(font)
+
+        elif role == QtCore.Qt.BackgroundRole:
+            color = editor.factory.label_bg_color_
+            if color is not None:
+                return color
+
+        elif role == QtCore.Qt.ForegroundRole:
+            color = editor.factory.label_color_
+            if color is not None:
+                return color
+
         return None
 
     def insertRow(self, row, parent=QtCore.QModelIndex(), obj=None):
@@ -205,7 +244,7 @@ class TableModel(QtCore.QAbstractTableModel):
         editor = self._editor
         items = editor.items()
         self.beginInsertRows(parent, row, row + count - 1)
-        for i in xrange(count):
+        for i in range(count):
             editor.callx(items.insert, row + i, editor.create_new_row())
         self.endInsertRows()
         return True
@@ -217,7 +256,7 @@ class TableModel(QtCore.QAbstractTableModel):
         editor = self._editor
         items = editor.items()
         self.beginRemoveRows(parent, row, row + count - 1)
-        for i in xrange(count):
+        for i in range(count):
             editor.callx(items.pop, row + i)
         self.endRemoveRows()
         return True
@@ -237,7 +276,7 @@ class TableModel(QtCore.QAbstractTableModel):
 
         if selection_mode.startswith("cell"):
             data = [self._get_cell_drag_value(index.row(), index.column())
-                for index in indexes]
+                    for index in indexes]
         elif selection_mode.startswith("column"):
             columns = sorted(set(index.column() for index in indexes))
             data = self._get_columns_drag_value(columns)
@@ -249,10 +288,10 @@ class TableModel(QtCore.QAbstractTableModel):
 
         # handle re-ordering via internal drags
         if editor.factory.reorderable:
-            rows = sorted(set([ index.row() for index in indexes ]))
-            data = QtCore.QByteArray(str(id(self)))
+            rows = sorted({index.row() for index in indexes})
+            data = QtCore.QByteArray(six.text_type(id(self)).encode('utf8'))
             for row in rows:
-                data.append(' %i' % row)
+                data.append((' %i' % row).encode('utf8'))
             mime_data.setData(mime_type, data)
         return mime_data
 
@@ -265,15 +304,15 @@ class TableModel(QtCore.QAbstractTableModel):
         # this is a drag from a table model?
         data = mime_data.data(mime_type)
         if not data.isNull() and action == QtCore.Qt.MoveAction:
-            id_and_rows = map(int, str(data).split(' '))
+            id_and_rows = [int(s) for s in data.data().decode('utf8').split(' ')]
             table_id = id_and_rows[0]
             # is it from ourself?
             if table_id == id(self):
                 current_rows = id_and_rows[1:]
                 if not parent.isValid():
-                    row = len(self._editor.items())-1
+                    row = len(self._editor.items()) - 1
                 else:
-                    row == parent.row()
+                    row = parent.row()
 
                 self.moveRows(current_rows, row)
                 return True
@@ -300,9 +339,9 @@ class TableModel(QtCore.QAbstractTableModel):
 
         return QtCore.Qt.MoveAction
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Utility methods
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def _get_columns_drag_value(self, columns):
         """ Returns the value to use when the specified columns are dragged or
@@ -333,9 +372,9 @@ class TableModel(QtCore.QAbstractTableModel):
         drag_value = editor.columns[column].get_drag_value(item)
         return drag_value
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  TableModel interface:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def moveRow(self, old_row, new_row):
         """Convenience method to move a single row."""
@@ -372,9 +411,10 @@ class TableModel(QtCore.QAbstractTableModel):
         # Update the selection for the new location.
         self._editor.set_selection(objects)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'SortFilterTableModel' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
+
 
 class SortFilterTableModel(QtGui.QSortFilterProxyModel):
     """A wrapper for the TableModel which provides sorting and filtering
@@ -387,9 +427,9 @@ class SortFilterTableModel(QtGui.QSortFilterProxyModel):
 
         self._editor = editor
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  QSortFilterProxyModel interface:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def filterAcceptsRow(self, source_row, source_parent):
         """"Reimplemented to use a TableFilter for filtering rows."""
@@ -405,7 +445,7 @@ class SortFilterTableModel(QtGui.QSortFilterProxyModel):
         return True
 
     def lessThan(self, left_mi, right_mi):
-        """Reimplemented to sort according to the 'cmp' method defined for
+        """Reimplemented to sort according to the 'key' method defined for
         TableColumn."""
 
         editor = self._editor
@@ -413,11 +453,11 @@ class SortFilterTableModel(QtGui.QSortFilterProxyModel):
         items = editor.items()
         left, right = items[left_mi.row()], items[right_mi.row()]
 
-        return column.cmp(left, right) < 0
+        return column.key(left) < column.key(right)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  SortFilterTableModel interface:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def moveRow(self, old_row, new_row):
         """Convenience method to move a single row."""
@@ -428,7 +468,7 @@ class SortFilterTableModel(QtGui.QSortFilterProxyModel):
         """Delegate to source model with mapped rows."""
 
         source = self.sourceModel()
-        current_rows = [ self.mapToSource(self.index(row, 0)).row()
-                         for row in current_rows ]
+        current_rows = [self.mapToSource(self.index(row, 0)).row()
+                        for row in current_rows]
         new_row = self.mapToSource(self.index(new_row, 0)).row()
         source.moveRows(current_rows, new_row)
