@@ -1,4 +1,4 @@
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #
 #  Copyright (c) 2009, Enthought, Inc.
 #  All rights reserved.
@@ -13,37 +13,42 @@
 #  Author: Evan Patterson
 #  Date:   06/22/2009
 #
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 """ A traits UI editor for editing tabular data (arrays, list of tuples, lists
     of objects, etc).
 """
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Imports:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
+
+from __future__ import absolute_import
+
+from contextlib import contextmanager
 
 from pyface.qt import QtCore, QtGui
-
 from pyface.image_resource import ImageResource
+from pyface.ui_traits import Image
 
 from traits.api import (Any, Bool, Callable, Event, HasStrictTraits, Instance,
-    Int, List, NO_COMPARE, Property, TraitListEvent)
+                        Int, List, NO_COMPARE, Property, TraitListEvent)
 
 from traitsui.tabular_adapter import TabularAdapter
-from traitsui.ui_traits import Image
-
-from editor import Editor
-from tabular_model import TabularModel
+from traitsui.helper import compute_column_widths
+from .editor import Editor
+from .tabular_model import TabularModel
+import six
 
 
-class HeaderEventFilter(QtCore.QObject) :
-    def __init__(self, editor) :
+class HeaderEventFilter(QtCore.QObject):
+
+    def __init__(self, editor):
         super(HeaderEventFilter, self).__init__()
         self.editor = editor
 
-    def eventFilter(self, obj, event) :
-        if event.type() == QtCore.QEvent.ContextMenu :
+    def eventFilter(self, obj, event):
+        if event.type() == QtCore.QEvent.ContextMenu:
             self.editor._on_column_context_menu(event.pos())
             return True
         return False
@@ -54,7 +59,7 @@ class TabularEditor(Editor):
         lists of objects, etc).
     """
 
-    #-- Trait Definitions ------------------------------------------------------
+    #-- Trait Definitions ----------------------------------------------------
 
     # The event fired when a table update is needed:
     update = Event
@@ -64,16 +69,20 @@ class TabularEditor(Editor):
 
     # The current set of selected items (which one is used depends upon the
     # initial state of the editor factory 'multi_select' trait):
-    selected       = Any
+    selected = Any
     multi_selected = List
 
     # The current set of selected item indices (which one is used depends upon
     # the initial state of the editor factory 'multi_select' trait):
-    selected_row        = Int(-1)
+    selected_row = Int(-1)
     multi_selected_rows = List(Int)
 
+    # The optional extended name of the trait to synchronize the selection
+    # column with:
+    selected_column = Int(-1)
+
     # The most recently actived item and its index:
-    activated     = Any(comparison_mode=NO_COMPARE)
+    activated = Any(comparison_mode=NO_COMPARE)
     activated_row = Int(comparison_mode=NO_COMPARE)
 
     # The most recent left click data:
@@ -97,11 +106,15 @@ class TabularEditor(Editor):
     # The event triggering scrolling.
     scroll_to_row = Event(Int)
 
+    # The event triggering scrolling.
+    scroll_to_column = Event(Int)
+
     # Is the tabular editor scrollable? This value overrides the default.
     scrollable = True
 
-    # Row index of item to select after rebuilding editor list:
-    row = Any
+    # NIT: This doesn't seem to be used anywhere...can I delete?
+    # # Row index of item to select after rebuilding editor list:
+    # row = Any
 
     # Should the selected item be edited after rebuilding the editor list:
     edit = Bool(False)
@@ -125,11 +138,11 @@ class TabularEditor(Editor):
 
     widget_factory = Callable(lambda *args, **kwds: _TableView(*args, **kwds))
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Editor interface:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def init (self, parent):
+    def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
         """
@@ -144,8 +157,11 @@ class TabularEditor(Editor):
         if factory.multi_select:
             self.sync_value(factory.selected, 'multi_selected', 'both',
                             is_list=True)
-            self.sync_value(factory.selected_row, 'multi_selected_rows','both',
-                            is_list=True)
+            self.sync_value(
+                factory.selected_row,
+                'multi_selected_rows',
+                'both',
+                is_list=True)
         else:
             self.sync_value(factory.selected, 'selected', 'both')
             self.sync_value(factory.selected_row, 'selected_row', 'both')
@@ -155,38 +171,38 @@ class TabularEditor(Editor):
             slot = self._on_rows_selection
         else:
             slot = self._on_row_selection
-        signal = 'selectionChanged(QItemSelection,QItemSelection)'
-        QtCore.QObject.connect(self.control.selectionModel(),
-                               QtCore.SIGNAL(signal), slot)
+        selection_model = self.control.selectionModel()
+        selection_model.selectionChanged.connect(slot)
 
         # Synchronize other interesting traits as necessary:
-        self.sync_value(factory.update, 'update', 'from')
-        self.sync_value(factory.refresh, 'refresh', 'from')
-        self.sync_value(factory.activated,     'activated',     'to')
+        self.sync_value(factory.update, 'update', 'from', is_event=True)
+        self.sync_value(factory.refresh, 'refresh', 'from', is_event=True)
+        self.sync_value(factory.activated, 'activated', 'to')
         self.sync_value(factory.activated_row, 'activated_row', 'to')
-        self.sync_value(factory.clicked,  'clicked',  'to')
+        self.sync_value(factory.clicked, 'clicked', 'to')
         self.sync_value(factory.dclicked, 'dclicked', 'to')
-        self.sync_value(factory.right_clicked,  'right_clicked',  'to')
+        self.sync_value(factory.right_clicked, 'right_clicked', 'to')
         self.sync_value(factory.right_dclicked, 'right_dclicked', 'to')
         self.sync_value(factory.column_clicked, 'column_clicked', 'to')
-        self.sync_value(factory.column_right_clicked, 'column_right_clicked', 'to')
-        self.sync_value(factory.scroll_to_row, 'scroll_to_row', 'from')
+        self.sync_value(
+            factory.column_right_clicked,
+            'column_right_clicked',
+            'to')
+        self.sync_value(factory.scroll_to_row, 'scroll_to_row', 'from',
+                        is_event=True)
+        self.sync_value(factory.scroll_to_column, 'scroll_to_column', 'from',
+                        is_event=True)
 
         # Connect other signals as necessary
-        signal = QtCore.SIGNAL('activated(QModelIndex)')
-        QtCore.QObject.connect(control, signal, self._on_activate)
-        signal = QtCore.SIGNAL('clicked(QModelIndex)')
-        QtCore.QObject.connect(control, signal, self._on_click)
-        signal = QtCore.SIGNAL('clicked(QModelIndex)')
-        QtCore.QObject.connect(control, signal, self._on_right_click)
-        signal = QtCore.SIGNAL('doubleClicked(QModelIndex)')
-        QtCore.QObject.connect(control, signal, self._on_dclick)
-        signal = QtCore.SIGNAL('sectionClicked(int)')
-        QtCore.QObject.connect(control.horizontalHeader(), signal, self._on_column_click)
+        control.activated.connect(self._on_activate)
+        control.clicked.connect(self._on_click)
+        control.clicked.connect(self._on_right_click)
+        control.doubleClicked.connect(self._on_dclick)
+        control.horizontalHeader().sectionClicked.connect(
+            self._on_column_click)
 
         control.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
-        signal = QtCore.SIGNAL('customContextMenuRequested(QPoint)')
-        QtCore.QObject.connect(control, signal, self._on_context_menu)
+        control.customContextMenuRequested.connect(self._on_context_menu)
 
         self.header_event_filter = HeaderEventFilter(self)
         control.horizontalHeader().installEventFilter(self.header_event_filter)
@@ -195,7 +211,7 @@ class TabularEditor(Editor):
         # replacements:
         try:
             self.context_object.on_trait_change(
-                self.update_editor, self.extended_name+'_items', dispatch='ui')
+                self.update_editor, self.extended_name + '_items', dispatch='ui')
         except:
             pass
 
@@ -218,7 +234,7 @@ class TabularEditor(Editor):
         self.on_trait_change(self.update_editor, 'adapter.columns',
                              dispatch='ui')
 
-    def dispose (self):
+    def dispose(self):
         """ Disposes of the contents of an editor.
         """
         self.context_object.on_trait_change(
@@ -242,15 +258,16 @@ class TabularEditor(Editor):
             editor.
         """
         if not self._no_update:
-            self.model.reset()
+            self.model.beginResetModel()
+            self.model.endResetModel()
             if self.factory.multi_select:
                 self._multi_selected_changed(self.multi_selected)
-            else :
+            else:
                 self._selected_changed(self.selected)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  TabularEditor interface:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def refresh_editor(self):
         """ Requests the table view to redraw itself.
@@ -278,9 +295,9 @@ class TabularEditor(Editor):
         finally:
             self._no_notify = old
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  UI preference save/restore interface:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def restore_prefs(self, prefs):
         """ Restores any saved user preference information associated with the
@@ -289,19 +306,19 @@ class TabularEditor(Editor):
         cws = prefs.get('cached_widths')
         num_columns = len(self.adapter.columns)
         if cws is not None and num_columns == len(cws):
-            for column in xrange(num_columns):
+            for column in range(num_columns):
                 self.control.setColumnWidth(column, cws[column])
 
     def save_prefs(self):
         """ Returns any user preference information associated with the editor.
         """
-        widths = [ self.control.columnWidth(column)
-                   for column in xrange(len(self.adapter.columns)) ]
-        return { 'cached_widths': widths }
+        widths = [self.control.columnWidth(column)
+                  for column in range(len(self.adapter.columns))]
+        return {'cached_widths': widths}
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Private methods:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def _add_image(self, image_resource):
         """ Adds a new image to the image map.
@@ -316,7 +333,7 @@ class TabularEditor(Editor):
     def _get_image(self, image):
         """ Converts a user specified image to a QIcon.
         """
-        if isinstance(image, basestring):
+        if isinstance(image, six.string_types):
             self.image = image
             image = self.image
 
@@ -336,7 +353,21 @@ class TabularEditor(Editor):
                                    column=index.column())
         setattr(self, trait, event)
 
-    #-- Trait Event Handlers ---------------------------------------------------
+    #-- Trait Event Handlers -------------------------------------------------
+
+    def _clicked_changed(self):
+        """ When mouse is clicked on a specific cell, update the selected
+            indices first
+        """
+        if not self.factory.multi_select:
+            self.selected_row = self.clicked.row
+            self.selected_column = self.clicked.column
+
+    def _column_clicked_changed(self):
+        """ When column is clicked, update selected column first
+        """
+        if not self.factory.multi_select:
+            self.selected_column = self.clicked.column
 
     def _update_changed(self):
         self.update_editor()
@@ -346,28 +377,39 @@ class TabularEditor(Editor):
 
     def _selected_changed(self, new):
         if not self._no_update:
-            try:
-                selected_row = self.value.index(new)
-            except:
-                pass
+            if new is None:
+                self._selected_row_changed(-1)
             else:
-                self._selected_row_changed(selected_row)
+                try:
+                    selected_row = self.value.index(new)
+                except Exception:
+                    from traitsui.api import raise_to_debug
+                    raise_to_debug()
+                else:
+                    self._selected_row_changed(selected_row)
 
     def _selected_row_changed(self, selected_row):
         if not self._no_update:
             smodel = self.control.selectionModel()
-            if selected_row == -1:
+            if selected_row < 0:
                 smodel.clearSelection()
             else:
-                smodel.select(self.model.index(selected_row, 0),
-                              QtGui.QItemSelectionModel.ClearAndSelect |
-                              QtGui.QItemSelectionModel.Rows)
+                smodel.select(
+                    self.model.index(
+                        selected_row,
+                        max(self.selected_column, 0)
+                    ),
+                    QtGui.QItemSelectionModel.ClearAndSelect |
+                    QtGui.QItemSelectionModel.Rows
+                )
+                # Once selected, scroll to the row
+                self.scroll_to_row = selected_row
 
     def _multi_selected_changed(self, new):
         if not self._no_update:
             values = self.value
             try:
-                rows = [ values.index(i) for i in new]
+                rows = [values.index(i) for i in new]
             except:
                 pass
             else:
@@ -376,8 +418,8 @@ class TabularEditor(Editor):
     def _multi_selected_items_changed(self, event):
         values = self.value
         try:
-            added = [ values.index(item) for item in event.added ]
-            removed = [ values.index(item) for item in event.removed ]
+            added = [values.index(item) for item in event.added]
+            removed = [values.index(item) for item in event.removed]
         except:
             pass
         else:
@@ -389,37 +431,70 @@ class TabularEditor(Editor):
             smodel = self.control.selectionModel()
             selection = QtGui.QItemSelection()
             for row in selected_rows:
-                selection.select(self.model.index(row, 0), self.model.index(row, 0))
+                selection.select(
+                    self.model.index(
+                        row, 0), self.model.index(
+                        row, 0))
             smodel.clearSelection()
             smodel.select(selection,
-                QtGui.QItemSelectionModel.Select |
-                QtGui.QItemSelectionModel.Rows)
-
-    def _multi_selected_rows_items_changed(self, event):
-        smodel = self.control.selectionModel()
-        for row in event.removed:
-            smodel.select(self.model.index(row, 0),
-                          QtGui.QItemSelectionModel.Deselect |
-                          QtGui.QItemSelectionModel.Rows)
-        for row in event.added:
-            smodel.select(self.model.index(row, 0),
                           QtGui.QItemSelectionModel.Select |
                           QtGui.QItemSelectionModel.Rows)
 
+    def _multi_selected_rows_items_changed(self, event):
+        if not self._no_update:
+            smodel = self.control.selectionModel()
+            for row in event.removed:
+                smodel.select(self.model.index(row, 0),
+                            QtGui.QItemSelectionModel.Deselect |
+                            QtGui.QItemSelectionModel.Rows)
+            for row in event.added:
+                smodel.select(self.model.index(row, 0),
+                            QtGui.QItemSelectionModel.Select |
+                            QtGui.QItemSelectionModel.Rows)
+
+    def _selected_column_changed(self, selected_column):
+        if not self._no_update:
+            smodel = self.control.selectionModel()
+            if selected_column >= 0:
+                smodel.select(
+                    self.model.index(
+                        max(self.selected_row, 0),
+                        selected_column
+                    ),
+                    QtGui.QItemSelectionModel.ClearAndSelect |
+                    QtGui.QItemSelectionModel.Rows
+                )
+                # Once selected, scroll to the column
+                self.scroll_to_column = selected_column
+
     scroll_to_row_hint_map = {
-        'center'  : QtGui.QTableView.PositionAtCenter,
-        'top'     : QtGui.QTableView.PositionAtTop,
-        'bottom'  : QtGui.QTableView.PositionAtBottom,
-        'visible' : QtGui.QTableView.EnsureVisible,
+        'center': QtGui.QTableView.PositionAtCenter,
+        'top': QtGui.QTableView.PositionAtTop,
+        'bottom': QtGui.QTableView.PositionAtBottom,
+        'visible': QtGui.QTableView.EnsureVisible,
     }
 
     def _scroll_to_row_changed(self, row):
         """ Scroll to the given row.
         """
-        scroll_hint = self.scroll_to_row_hint_map.get(self.factory.scroll_to_row_hint, self.control.PositionAtCenter)
-        self.control.scrollTo(self.model.index(row, 0), scroll_hint)
+        scroll_hint = self.scroll_to_row_hint_map.get(
+            self.factory.scroll_to_row_hint, self.control.PositionAtCenter)
+        self.control.scrollTo(
+            self.model.index(row, max(self.selected_column, 0)),
+            scroll_hint
+        )
 
-    #-- Table Control Event Handlers -------------------------------------------
+    def _scroll_to_column_changed(self, column):
+        """ Scroll to the given column.
+        """
+        scroll_hint = self.scroll_to_row_hint_map.get(
+            self.factory.scroll_to_row_hint, self.control.PositionAtCenter)
+        self.control.scrollTo(
+            self.model.index(max(self.selected_row, 0), column),
+            scroll_hint
+        )
+
+    #-- Table Control Event Handlers -----------------------------------------
 
     def _on_activate(self, index):
         """ Handle a cell being activated.
@@ -483,32 +558,40 @@ class TabularEditor(Editor):
         finally:
             self._no_update = False
 
-    def _on_context_menu(self, pos) :
-        column, row = self.control.columnAt(pos.x()), self.control.rowAt(pos.y())
+    def _on_context_menu(self, pos):
+        column, row = self.control.columnAt(
+            pos.x()), self.control.rowAt(
+            pos.y())
         menu = self.adapter.get_menu(self.object, self.name, row, column)
-        if menu :
-            self._menu_context = {'selection' : self.object,
-                             'object':  self.object,
-                             'editor':  self,
-                             'column':  column,
-                             'row':     row,
-                             'item':    self.adapter.get_item(self.object, self.name, row),
-                             'info':    self.ui.info,
-                             'handler': self.ui.handler }
-            qmenu = menu.create_menu( self.control, self )
+        if menu:
+            self._menu_context = {
+                'selection': self.object,
+                'object': self.object,
+                'editor': self,
+                'column': column,
+                'row': row,
+                'item': self.adapter.get_item(
+                    self.object,
+                    self.name,
+                    row),
+                'info': self.ui.info,
+                'handler': self.ui.handler}
+            qmenu = menu.create_menu(self.control, self)
             qmenu.exec_(self.control.mapToGlobal(pos))
             self._menu_context = None
 
-    def _on_column_context_menu(self, pos) :
+    def _on_column_context_menu(self, pos):
         column = self.control.columnAt(pos.x())
         menu = self.adapter.get_column_menu(self.object, self.name, -1, column)
-        if menu :
-            self._menu_context = {'selection' : self.object, 'object':  self.object,
-                             'editor':  self,
-                             'column':  column,
-                             'info':    self.ui.info,
-                             'handler': self.ui.handler }
-            qmenu = menu.create_menu( self.control, self )
+        if menu:
+            self._menu_context = {
+                'selection': self.object,
+                'object': self.object,
+                'editor': self,
+                'column': column,
+                'info': self.ui.info,
+                'handler': self.ui.handler}
+            qmenu = menu.create_menu(self.control, self)
             qmenu.exec_(self.control.mapToGlobal(pos))
             self._menu_context = None
         else:
@@ -516,9 +599,9 @@ class TabularEditor(Editor):
             self._on_column_right_click(column)
 
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'TabularEditorEvent' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 class TabularEditorEvent(HasStrictTraits):
 
@@ -531,20 +614,21 @@ class TabularEditorEvent(HasStrictTraits):
     # The row item:
     item = Property
 
-    #-- Private Traits ---------------------------------------------------------
+    #-- Private Traits -------------------------------------------------------
 
     # The editor the event is associated with:
     editor = Instance(TabularEditor)
 
-    #-- Property Implementations -----------------------------------------------
+    #-- Property Implementations ---------------------------------------------
 
     def _get_item(self):
         editor = self.editor
         return editor.adapter.get_item(editor.object, editor.name, self.row)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Qt widgets that have been configured to behave as expected by Traits UI:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
+
 
 class _ItemDelegate(QtGui.QStyledItemDelegate):
     """ A QStyledItemDelegate which draws its owns gridlines so that we can
@@ -572,12 +656,15 @@ class _ItemDelegate(QtGui.QStyledItemDelegate):
         painter.setPen(option.palette.color(QtGui.QPalette.Dark))
 
         if self._horizontal_lines:
-            painter.drawLine(option.rect.bottomLeft(),option.rect.bottomRight())
+            painter.drawLine(
+                option.rect.bottomLeft(),
+                option.rect.bottomRight())
         if self._vertical_lines:
             painter.drawLine(option.rect.topRight(), option.rect.bottomRight())
 
         painter.restore()
 
+
 class _TableView(QtGui.QTableView):
     """ A QTableView configured to behave as expected by TraitsUI.
     """
@@ -587,7 +674,8 @@ class _TableView(QtGui.QTableView):
         """
         QtGui.QTableView.__init__(self)
 
-        self._initial_size = False
+        self._user_widths = None
+        self._is_resizing = False
         self._editor = editor
         self.setModel(editor.model)
         factory = editor.factory
@@ -608,14 +696,22 @@ class _TableView(QtGui.QTableView):
             # we make a reasonable guess based on the minimum size hint and the font
             # of the first row.
             size = vheader.minimumSectionSize()
-            font = editor.adapter.get_font(editor.object, editor.name, 0)
+
+            # Check if any columns have been added, and use their font, otherwise
+            # use the default font
+            font = None
+            if 0 in editor.adapter.column_map:
+                font = editor.adapter.get_font(editor.object, editor.name, 0)
             if font is not None:
-                size = max(size, QtGui.QFontMetrics(QtGui.QFont(font)).height())
+                size = max(
+                    size, QtGui.QFontMetrics(
+                        QtGui.QFont(font)).height())
             vheader.setDefaultSectionSize(size)
 
         # Configure the column headings.
         hheader = self.horizontalHeader()
         hheader.setStretchLastSection(factory.stretch_last_section)
+        hheader.sectionResized.connect(self.columnResized)
         if factory.show_titles:
             hheader.setHighlightSections(False)
         else:
@@ -639,6 +735,8 @@ class _TableView(QtGui.QTableView):
             self.viewport().setAcceptDrops(True)
         if factory.drag_move:
             self.setDragDropMode(QtGui.QAbstractItemView.InternalMove)
+        else:
+            self.setDragDropMode(QtGui.QAbstractItemView.DragDrop)
         self.setDropIndicatorShown(True)
 
     def keyPressEvent(self, event):
@@ -651,7 +749,7 @@ class _TableView(QtGui.QTableView):
         # most platforms, which is why we do this here.
         if (event.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return) and
             self.state() != QtGui.QAbstractItemView.EditingState and
-            factory.editable and 'edit' in factory.operations):
+                factory.editable and 'edit' in factory.operations):
             if factory.multi_select:
                 rows = editor.multi_selected_rows
                 row = rows[0] if len(rows) == 1 else -1
@@ -695,7 +793,7 @@ class _TableView(QtGui.QTableView):
         sh = QtGui.QTableView.sizeHint(self)
 
         width = 0
-        for column in xrange(len(self._editor.adapter.columns)):
+        for column in range(len(self._editor.adapter.columns)):
             width += self.sizeHintForColumn(column)
         sh.setWidth(width)
 
@@ -707,12 +805,13 @@ class _TableView(QtGui.QTableView):
             space be known, we have to wait until the UI that contains this
             table gives it its initial size.
         """
-        QtGui.QTableView.resizeEvent(self, event)
+        super(_TableView, self).resizeEvent(event)
 
         parent = self.parent()
-        if (not self._initial_size and parent and
-            (self.isVisible() or isinstance(parent, QtGui.QMainWindow))):
-            self._initial_size = True
+        if (
+            parent
+            and (self.isVisible() or isinstance(parent, QtGui.QMainWindow))
+        ):
             self.resizeColumnsToContents()
 
     def sizeHintForColumn(self, column):
@@ -734,34 +833,50 @@ class _TableView(QtGui.QTableView):
 
     def resizeColumnsToContents(self):
         """ Reimplemented to support proportional column width specifications.
-            For information about the layout algorithm, see
-            https://svn.enthought.com/enthought/wiki/Traits_3_0_tabular_editor.
+
+        The core part of the computation is carried out in
+        :func:`traitsui.helpers.compute_column_widths`
         """
         editor = self._editor
+        adapter = editor.adapter
         if editor.factory.auto_resize:
             # Use the default implementation.
             return super(_TableView, self).resizeColumnsToContents()
+
         available_space = self.viewport().width()
+        requested = []
+        min_widths = []
+        for column in range(len(adapter.columns)):
+            width = adapter.get_width(editor.object, editor.name, column)
+            requested.append(width)
+            min_widths.append(self.sizeHintForColumn(column))
+
+        widths = compute_column_widths(
+            available_space, requested, min_widths, self._user_widths
+        )
+
         hheader = self.horizontalHeader()
-
-        # Assign sizes for columns with absolute size requests
-        percent_vals, percent_cols = [], []
-        for column in xrange(len(editor.adapter.columns)):
-            width = editor.adapter.get_width(editor.object, editor.name, column)
-            if width > 1:
-                available_space -= width
+        with self._resizing():
+            for column, width in enumerate(widths):
                 hheader.resizeSection(column, width)
-            else:
-                if width <= 0:
-                    width = 0.1
-                percent_vals.append(width)
-                percent_cols.append(column)
 
-        # Now use the remaining space for columns with proportional or no width
-        # requests.
-        percent_total = sum(percent_vals)
-        for i, column in enumerate(percent_cols):
-            percent = percent_vals[i] / percent_total
-            width = max(30, int(percent * available_space))
-            hheader.resizeSection(column, width)
+    def columnResized(self, index, old, new):
+        """ Handle user-driven resizing of columns.
 
+        This affects the column widths when not using auto-sizing.
+        """
+        if not self._is_resizing:
+            if self._user_widths is None:
+                self._user_widths = [None] * len(self._editor.adapter.columns)
+            self._user_widths[index] = new
+            if not self._editor.factory.auto_resize:
+                self.resizeColumnsToContents()
+
+    @contextmanager
+    def _resizing(self):
+        """ Context manager that guards against recursive column resizing. """
+        self._is_resizing = True
+        try:
+            yield
+        finally:
+            self._is_resizing = False
